==> oeshop_0.01.tar.gz: oeshop/admin/prize_admin/prize_view.php <==
<?php
//require_once("../admin_auth.php");
if (file_exists("../../lib/connect.php")) { require_once("../../lib/connect.php"); }
require_once("../lib/prize_lib.php");

if (empty($HTTP_GET_VARS[id])) {
	err_msg("ǰID Է ֽʽÿ!");
	exit;
}
else {
	$row = read_prize($HTTP_GET_VARS[id], $db_conn);

	// ̹ ɼǼ
	$t_img = explode("@", $row[img_option]);
	$i = 0;
	foreach ($t_img as $temp) {
		$img_option[$i] = explode(":", $temp);
	}
}

//  ϶
if ($action = "edit") {
	$frm_action = "prize_edit.php";
}
// ߰ ϶
else {
	$frm_action = "prize_add.php";
}
?>

<!---
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - ǰ / 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
---->

<html>
<head>
<title>OEShop :::::::::: ǰ </title>
<meta http-equiv='Content-Type' content='text/html; charset=euc-kr'>
<link rel='stylesheet' href='../admin.css' type='text/css'>

<script language='javascript'>
function check_form() {
	
}
</script>
</head>
<body bgcolor="#FFFFFF" text='#000000' marginwidth='0' marginheight='0' leftmargin='0' topmargin='0'>

<form method='post' name='FrmAdd' action='<?=$frm_action?>'>
<table width='98%' border='0' cellpadding='0' cellspacing='0' align='center'>
<tr><td>
<a href='javascript:history.go(-1);'><img src='images/return.gif' border='0' alt=' ư'></a>
<a href='javascript:check_form();'><img src='images/submit.gif' border='0'></a>
</td></tr>
</table>
<br>

<table width='98%' border='0' cellpadding='2' cellspacing='1' align='center' bgcolor='#BCBCBC'>
<tr>
<td bgcolor='#265293' width='100' align='right'><font color='#FFFFFF'>зڵ</font></td>
<td bgcolor='#FFFFFF'>
<input type='text' name='category_code' value='<?=$HTTP_GET_VARS[category_code]?>'>
<img src='images/search_cat.gif' border='0' align='absmiddle'>
<img src='images/copy.gif' border='0' align='absmiddle'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰȣ</font></td>
<td bgcolor='#FFFFFF'>
<input type='text' name='prize_num' value='<?=$row[prize_num]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ</font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_num' value='<?=$row[prize_name]?>' size='50'></td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰݾ</font></td>
<td bgcolor='#FFFFFF'>
Һڰ : <input type='text' name='prize_sail1' value='<?=$row[prize_sail1]?>'>  /
ǸŰ : <input type='text' name='prize_sail2' value='<?=$row[prize_sail2]?>'> 
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>Ʈ</font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_poing' value='<?=$row[prize_point]?>'> Ʈ</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'></font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_poing' value='<?=$row[prize_amount]?>'> </td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ̹</font></td>
<td bgcolor='#FFFFFF'>
<input type='file' name='view_img' size='40'><br>

<?php
if (file_exists("../../pds/shop_img/".$row[view_img])) {
	echo "<font color='navy'>".$row[view_img]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>

</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ1</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option1' value='<?=$row[option1]?>'> /
 : <input type='text' name='option_val1' value='<?=$row[option_val1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ2</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option2' value='<?=$row[option2]?>'> /
 : <input type='text' name='option_val2' value='<?=$row[option_val2]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ3</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option3' value='<?=$row[option3]?>'> /
 : <input type='text' name='option_val3' value='<?=$row[option_val3]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ1</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option1' value='<?=$img_option[0][0]?>'> /
 : <input type='file' size='40' name='img_option_v1' value='<?=$img_option[0][1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ2</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option2' value='<?=$img_option[1][0]?>'> /
 : <input type='file' size='40' name='img_option_v2' value='<?=$img_option[1][1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ3</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option3' value='<?=$img_option[2][0]?>'> /
 : <input type='file' size='40' name='img_option_v3' value='<?=$img_option[2][1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ4</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option4' value='<?=$img_option[3][0]?>'> /
 : <input type='file' size='40' name='img_option_v4' value='<?=$img_option[3][1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ5</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option5' value='<?=$img_option[4][0]?>'> /
 : <input type='file' size='40' name='img_option_v5' value='<?=$img_option[4][1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>Ÿɼ</font></td>
<td bgcolor='#FFFFFF'>

	<table width='100%' border='0' cellpadding='2' cellspacing='0'>
	<tr>
	<td><input type='checkbox' name='prize_view' value='Y' <?if ($row[prize_view] == "Y") { echo "checked"; }?>> ǰ</td>
	<td><input type='checkbox' name='prize_recommand' value='Y' <?if ($row[prize_recommand] == "Y") { echo "checked"; }?>> õǰ</td>
	<td><input type='checkbox' name='prize_popular' value='Y' <?if ($row[prize_popular] == "Y") { echo "checked"; }?>> αǰ</td>
	<td><input type='checkbox' name='prize_new' value='Y' <?if ($row[prize_new] == "Y") { echo "checked"; }?>> Żǰ</td>
	</tr>
	<tr>
	<td><input type='checkbox' name='prize_mrecommand' value='Y' <?if ($row[prize_mrecommand] == "Y") { echo "checked"; }?>> õǰ</td>
	<td><input type='checkbox' name='prize_mpopular' value='Y' <?if ($row[prize_mpopular] == "Y") { echo "checked"; }?>> αǰ</td>
	<td><input type='checkbox' name='prize_mnew' value='Y' <?if ($row[prize_mnew] == "Y") { echo "checked"; }?>> νŻǰ</td>
	<td>&nbsp;</td>
	</tr>
	</table>

</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ</font></td>
<td bgcolor='#FFFFFF'>
<textarea name='body' cols='80' rows='15'><?=$row[body]?></textarea>
</td>
</tr>
</table>
<br>

<table width='98%' border='0' cellpadding='0' cellspacing='0' align='center'>
<tr><td>
<a href='javascript:history.go(-1);'><img src='images/return.gif' border='0' alt=' ư'></a>
<a href='javascript:check_form();'><img src='images/submit.gif' border='0'></a>
</td></tr>
</table>
</form>

</body>
</html>

==> oeshop_0.03.tar.gz: oeshop/admin/prize_admin/prize_view.php <==
<?php
//require_once("../admin_auth.php");
if (file_exists("../../lib/connect.php")) { require_once("../../lib/connect.php"); }
require_once("../lib/prize_lib.php");

if (empty($HTTP_GET_VARS[prize_num])) {
	err_msg("ǰȣ Է ֽʽÿ!");
	exit;
}
else {
	$row = read_prize($HTTP_GET_VARS[id], $db_conn);

	// ̹ ɼǼ
	$t_img = explode("@", $row[img_option]);
	$i = 0;
	foreach ($t_img as $temp) {
		$img_option[$i] = explode(":", $temp);
		$i++;
	}
}
?>

<!---
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - ǰ / 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
---->

<html>
<head>
<title>OEShop :::::::::: ǰ </title>
<meta http-equiv='Content-Type' content='text/html; charset=euc-kr'>
<link rel='stylesheet' href='../admin.css' type='text/css'>

<script language='javascript'>
function check_form() {
	var frm = document.FrmAdd;
	frm.submit();
}
</script>
</head>
<body bgcolor="#FFFFFF" text='#000000' marginwidth='0' marginheight='0' leftmargin='0' topmargin='0'>

<form method='post' name='FrmAdd' action='php/prize_edit.php' enctype='multipart/form-data'>
<input type='hidden' name='action' value='<?=$HTTP_GET_VARS[action]?>'>
<input type='hidden' name='prize_num' value='<?=$HTTP_GET_VARS[prize_num]?>'>
<input type='hidden' name='page' value='<?=$HTTP_GET_VARS[page]?>'>
<input type='hidden' name='scale' value='<?=$HTTP_GET_VARS[scale]?>'>
<input type='hidden' name='search_item' value='<?=$HTTP_GET_VARS[search_item]?>'>
<input type='hidden' name='search_val' value='<?=$HTTP_GET_VARS[search_val]?>'>

<table width='98%' border='0' cellpadding='0' cellspacing='0' align='center'>
<tr><td>
<a href='javascript:history.go(-1);'><img src='images/return.gif' border='0' alt=' ư'></a>
<a href='javascript:check_form();'><img src='images/submit.gif' border='0'></a>
</td></tr>
</table>
<br>

<table width='98%' border='0' cellpadding='2' cellspacing='1' align='center' bgcolor='#BCBCBC'>
<tr>
<td bgcolor='#265293' width='100' align='right'><font color='#FFFFFF'>зڵ</font></td>
<td bgcolor='#FFFFFF'>
<input type='text' name='category_code' value='<?=$HTTP_GET_VARS[category_code]?>'>
<img src='images/search_cat.gif' border='0' align='absmiddle'>
<img src='images/copy.gif' border='0' align='absmiddle'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰȣ</font></td>
<td bgcolor='#FFFFFF'>
<input type='text' name='prize_num' value='<?=$row[prize_num]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ</font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_name' value='<?=$row[prize_name]?>' size='50'></td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰݾ</font></td>
<td bgcolor='#FFFFFF'>
Һڰ : <input type='text' name='prize_sail1' value='<?=$row[prize_sail1]?>'>  /
ǸŰ : <input type='text' name='prize_sail2' value='<?=$row[prize_sail2]?>'> 
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>Ʈ</font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_point' value='<?=$row[prize_point]?>'> Ʈ</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'></font></td>
<td bgcolor='#FFFFFF'><input type='text' name='prize_amount' value='<?=$row[prize_amount]?>'> </td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ̹</font></td>
<td bgcolor='#FFFFFF'>
<input type='file' name='view_img' size='40'><br>

<?php
if (file_exists("../../pds/shop_img/".$row[view_img])) {
	echo "<font color='navy'>".$row[view_img]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>

</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ1</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option1' value='<?=$row[option1]?>'> /
 : <input type='text' name='option_val1' value='<?=$row[option_val1]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ2</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option2' value='<?=$row[option2]?>'> /
 : <input type='text' name='option_val2' value='<?=$row[option_val2]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ ɼ3</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='option3' value='<?=$row[option3]?>'> /
 : <input type='text' name='option_val3' value='<?=$row[option_val3]?>'>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ1</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option1' value='<?=$img_option[0][0]?>'> /
 : <input type='file' size='40' name='img_option_v1'>
<br>
<?php
if (file_exists("../../pds/option1/".$img_option[0][1]) && !empty($img_option[0][1])) {
	echo "<font color='navy'>".$img_option[0][1]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ2</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option2' value='<?=$img_option[1][0]?>'> /
 : <input type='file' size='40' name='img_option_v2'>
<br>
<?php
if (file_exists("../../pds/option2/".$img_option[1][1]) && !empty($img_option[1][1])) {
	echo "<font color='navy'>".$img_option[1][1]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ3</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option3' value='<?=$img_option[2][0]?>'> /
 : <input type='file' size='40' name='img_option_v3'>
<br>
<?php
if (file_exists("../../pds/option3/".$img_option[2][1]) && !empty($img_option[2][1])) {
	echo "<font color='navy'>".$img_option[2][1]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ4</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option4' value='<?=$img_option[3][0]?>'> /
 : <input type='file' size='40' name='img_option_v4'>
<br>
<?php
if (file_exists("../../pds/option4/".$img_option[3][1]) && !empty($img_option[3][1])) {
	echo "<font color='navy'>".$img_option[3][1]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>̹ ɼ5</font></td>
<td bgcolor='#FFFFFF'>
 : <input type='text' name='img_option5' value='<?=$img_option[4][0]?>'> /
 : <input type='file' size='40' name='img_option_v5'>
<br>
<?php
if (file_exists("../../pds/option5/".$img_option[4][1]) && !empty($img_option[4][1])) {
	echo "<font color='navy'>".$img_option[4][1]." () ϵǾֽϴ.</font>";
}
else {
	echo "<font color='red'>!! ϵ ̹ ų ߸Ǿϴ !!</font>";
}
?>
</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>Ÿɼ</font></td>
<td bgcolor='#FFFFFF'>

	<table width='100%' border='0' cellpadding='2' cellspacing='0'>
	<tr>
	<td><input type='checkbox' name='prize_view' value='Y' <?if ($row[prize_view] == "Y") { echo "checked"; }?>> ǰ</td>
	<td><input type='checkbox' name='prize_recommand' value='Y' <?if ($row[prize_recommand] == "Y") { echo "checked"; }?>> õǰ</td>
	<td><input type='checkbox' name='prize_popular' value='Y' <?if ($row[prize_popular] == "Y") { echo "checked"; }?>> αǰ</td>
	<td><input type='checkbox' name='prize_new' value='Y' <?if ($row[prize_new] == "Y") { echo "checked"; }?>> Żǰ</td>
	</tr>
	<tr>
	<td><input type='checkbox' name='prize_mrecommand' value='Y' <?if ($row[prize_mrecommand] == "Y") { echo "checked"; }?>> õǰ</td>
	<td><input type='checkbox' name='prize_mpopular' value='Y' <?if ($row[prize_mpopular] == "Y") { echo "checked"; }?>> αǰ</td>
	<td><input type='checkbox' name='prize_mnew' value='Y' <?if ($row[prize_mnew] == "Y") { echo "checked"; }?>> νŻǰ</td>
	<td>&nbsp;</td>
	</tr>
	</table>

</td>
</tr>
<tr>
<td bgcolor='#265293' align='right'><font color='#FFFFFF'>ǰ</font></td>
<td bgcolor='#FFFFFF'>
<textarea name='body' cols='80' rows='15'><?=$row[body]?></textarea>
</td>
</tr>
</table>
<br>

<table width='98%' border='0' cellpadding='0' cellspacing='0' align='center'>
<tr><td>
<a href='javascript:history.go(-1);'><img src='images/return.gif' border='0' alt=' ư'></a>
<a href='javascript:check_form();'><img src='images/submit.gif' border='0'></a>
</td></tr>
</table>
</form>

</body>
</html>
